/***************************************************************************/
#define PACKETLEN 2048 /* Packet length for data transfer. Variable on VAX/VMS */

/***************************************************************************/
#define XFR_ROOTUID   0  /* Userid of root account - transfers to root can be blocked */
#define XFR_BLOCKROOT 1  /* If true, block transfers to privileged account */

/***************************************************************************/
#define XFR_TRNDIR "transfer"    /* Name of destination directory for xfer'd files  */
#define XFR_TRNMODE 0700         /* Creation mode for transfer directory (in octal) */
#define XFR_TRNWRACS 0200        /* Required access mode of transfer dir (u+w)      */
#define XFR_TRNWRMSK 0577        /* Mask for transfer dir access mode (inverse)     */

/***************************************************************************/
/* Min percentage of disk to be available after file xfer, or else transfer fails */
#define XFR_DISKFREE  2
#define XFR_DISKBLKSIZ 1024      /* Disk block size, for transfers from VAX/VMS */

/***************************************************************************/
#define XFR_CNCT_TO 60  /* Server connect timeout, for clearing zombie processes */
#define XFR_DATA_TO 180 /* Data transfer timeout, for reading and writing data   */

/***************************************************************************/
#define XFR_SERVICE "xfer" /* Transfer server program name in the /etc/services file */
#define XFR_DEFSRV  1500   /* default service number if "xfer" service not found */
#define XFR_TRYDEFSRV 1    /* attempt to use XFR_DEFSRV if "xfer" service not found? */

#define XFR_DATAFLAG  9999  /* Flag indicating end of data stream */

/***************************************************************************/
/*  File types - used when checking to see if a file exists. */
#define XFR_LINK  1
#define XFR_DIR   2
#define XFR_FILE  3

/***************************************************************************/
/* Transfer daemon (server) commands */
#define XFR_CMD_USER "user"   /* Initialize user session */
#define XFR_CMD_FILE "file"   /* Initialize a file transfer */
#define XFR_CMD_DATA "data"   /* Begin data transfer for a file */
#define XFR_CMD_CKSM "cksm"   /* File checksum */
#define XFR_CMD_QUIT "quit"   /* Close session, exit */
#define XFR_CMD_HELP "help"   /* User help for server commands */

/***************************************************************************/
/* Acknowledgements, error codes, and error messages below. */

/* No error */
#define XFR_NOERR     0
#define XFR_NOERR_S   "Command completed successfully"

/* Generic network errors */
#define XFR_NETERR    101
#define XFR_NETERR_S  "Generic network error"
#define XFR_INVCMD    102
#define XFR_INVCMD_S  "Invalid command.  Enter HELP."
#define XFR_NOCMD     103
#define XFR_NOCMD_S   "No command issued."

/* Init session errors */
#define XFR_IS_ERR    211

/* Verify user errors */
#define XFR_VF_NOUSER 301
#define XFR_VF_NOUSER_S "No such user exists"
#define XFR_VF_NOHOME 302
#define XFR_VF_NOHOME_S "Cant find home directory for specified user"
#define XFR_VF_TRNDIR 303
#define XFR_VF_TRNDIR_S "Could not access transfer direcotory for specified user"
#define XFR_VF_EUID   304
#define XFR_VF_EUID_S   "Cant access specified user account"
#define XFR_VF_UAV    305
#define XFR_VF_UAV_S     "User already specified"
#define XFR_VF_UNV    306
#define XFR_VF_UNV_S     "User not yet specified"
#define XFR_VF_MAIL   307
#define XFR_VF_MAIL_S    "Could not create mail message for user"
#define XFR_VF_ISSU   308
#define XFR_VF_ISSU_S    "Error - can not transfer files to privileged user"
#define XFR_VF_WTRN   309
#define XFR_VF_WTRN_S    "Specified user has blocked the receiving of network files"
#define XFR_VF_OTRN   310
#define XFR_VF_OTRN_S    "Specified user does not own existing transfer directory"

/* Open (local) file errors */
#define XFR_OF_COF    401
#define XFR_OF_COF_S    "Cant open specified local file"

/* Init (remote) file errors */
#define XFR_IF_COF    500  /* cant open file */
#define XFR_IF_COF_S    "Cant create remote file"
#define XFR_IF_DFL    501  /* disk full error */
#define XFR_IF_DFL_S    "Cant create remote file - disk too full"
#define XFR_IF_DST    502  /* disk status error */
#define XFR_IF_DST_S    "Cant access remote file system stats"
#define XFR_IF_AI     503
#define XFR_IF_AI_S     "A file was already initialized"

/* Send file data errors */
#define XFR_SD_FNI    600
#define XFR_SD_FNI_S    "File not yet initialized"
#define XFR_SD_CPP    601
#define XFR_SD_CPP_S    "Error writing packet"
#define XFR_SD_FSZ    602
#define XFR_SD_FSZ_S    "Warning - file received did not have expected length"

#define XFR_CS_MAIL   700
#define XFR_CS_MAIL_S   "Cant send mail to specified user"

#define XFR_HLP_MSG   800
#define XFR_HLP_MSG_S   "Valid commands: USER, FILE, DATA, QUIT, HELP"

#define XFR_CSM_BCSM  900
#define XFR_CSM_BCSM_S  "Error - file transferred had incorrect checksum"



#ifdef VAX
#define net_error(a) socket_perror(a)
#define EXITVAL 0x10000000
#else
#define net_error(a) perror(a)
#define EXITVAL 1
#endif
